From: Cedric Le Barz <clebarz@ektacom.com>
Date: Wed, 29 Mar 2023 23:10:48 +0200
Subject: [PATCH] Add track name information when track is written.
X-Unsent: 1
To: ffmpeg-devel@ffmpeg.org

Signed-off-by: Cedric Le Barz <clebarz@ektacom.com>
---
 ffmpeg/libavformat/mxfenc.c | 24 ++++++++++++++++++++++++
 1 file changed, 24 insertions(+)

diff --git a/ffmpeg/libavformat/mxfenc.c b/ffmpeg/libavformat/mxfenc.c
index 3bdf90a..bfbd5a6 100644
--- a/ffmpeg/libavformat/mxfenc.c
+++ b/ffmpeg/libavformat/mxfenc.c
@@ -299,6 +299,8 @@ static const MXFLocalTagPair mxf_local_tag_batch[] = {
     { 0x4B01, {0x06,0x0E,0x2B,0x34,0x01,0x01,0x01,0x02,0x05,0x30,0x04,0x05,0x00,0x00,0x00,0x00}}, /* Edit Rate */
     { 0x4B02, {0x06,0x0E,0x2B,0x34,0x01,0x01,0x01,0x02,0x07,0x02,0x01,0x03,0x01,0x03,0x00,0x00}}, /* Origin */
     { 0x4803, {0x06,0x0E,0x2B,0x34,0x01,0x01,0x01,0x02,0x06,0x01,0x01,0x04,0x02,0x04,0x00,0x00}}, /* Sequence reference */
+    // Track name
+    { 0x4802, {0x06,0x0E,0x2B,0x34,0x01,0x01,0x01,0x02,0x01,0x07,0x01,0x02,0x01,0x00,0x00,0x00}}, /* TrackName */
     // Sequence
     { 0x0201, {0x06,0x0E,0x2B,0x34,0x01,0x01,0x01,0x02,0x04,0x07,0x01,0x00,0x00,0x00,0x00,0x00}}, /* Data Definition UL */
     { 0x0202, {0x06,0x0E,0x2B,0x34,0x01,0x01,0x01,0x02,0x07,0x02,0x02,0x01,0x01,0x03,0x00,0x00}}, /* Duration */
@@ -862,7 +864,28 @@ static void mxf_write_track(AVFormatContext *s, AVStream *st, MXFPackage *packag
 
     mxf_write_metadata_key(pb, 0x013b00);
     PRINT_KEY(s, "track key", pb->buf_ptr - 16);
+
+    if (st->codecpar) {
+        static const char * pcTrackName_Video = "Picture" ;
+        static const char * pcTrackName_Audio = "Sound" ;
+        static const char * pcTrackName_Anc = "Ancillary" ;
+        if ( st->codecpar->codec_type == AVMEDIA_TYPE_VIDEO )
+        {
+            //TrackName Video
+            klv_encode_ber_length(pb, 80 + mxf_utf16_local_tag_length(pcTrackName_Video));
+            mxf_write_local_tag_utf16(s, 0x4802 , pcTrackName_Video);
+        } else if ( st->codecpar->codec_type == AVMEDIA_TYPE_AUDIO ) {
+            //TrackName Audio
+            klv_encode_ber_length(pb, 80 + mxf_utf16_local_tag_length(pcTrackName_Audio));
+            mxf_write_local_tag_utf16(s, 0x4802, pcTrackName_Audio);
+        } else {
+            //TrackName Ancillary
+            klv_encode_ber_length(pb, 80 + mxf_utf16_local_tag_length(pcTrackName_Anc));
+            mxf_write_local_tag_utf16(s, 0x4802, pcTrackName_Anc);
+        }
+    } else {
     klv_encode_ber_length(pb, 80);
+    }
 
     // write track uid
     mxf_write_local_tag(s, 16, 0x3C0A);
@@ -3383,3 +3406,4 @@ const FFOutputFormat ff_mxf_opatom_muxer = {
     .p.priv_class      = &mxf_opatom_muxer_class,
 };
 
+
-- 
2.34.1

